from textual.screen import ModalScreen
from textual.containers import Grid
from textual.binding import Binding

from textual.widgets import RadioSet, RadioButton, Label

class ChoiceModal(ModalScreen):

    CSS = """
    ChoiceModal {
        align: center middle;
        background: $primary 30%;
    }
    ChoiceModal Label {
        height: 1;
    }
    """

    BINDINGS = [
        ("j", "cursor_down", "Down"),
        ("k", "cursor_up", "Up"),
        # TODO: get this to work as override
        Binding("enter", "select", "Select", priority=True),
        ("c", "select", "Select"),
        ("escape", "cancel", "cancel")
    ]

    def __init__(self, enum, selected):
        self._enum = enum
        self.selected = selected
        super().__init__()

    def compose(self):
        yield Label(f"{self._enum.__name__}")
        yield RadioSet(
            *[
                RadioButton(str(e.value), value=self.selected==str(e.value)) for e in self._enum
            ]
        )

    def action_cursor_down(self):
        self.query_one(RadioSet).action_next_button()

    def action_cursor_up(self):
        self.query_one(RadioSet).action_previous_button()
    
    def action_select(self):
        rs = self.query_one(RadioSet)
        rs.action_toggle_button()
        pressed = rs.pressed_button
        self.dismiss(str(pressed.label))

    def action_cancel(self):
        self.app.pop_screen()
